@@ -6,20 +6,20 @@
 
 /** Column-reduction and reduction transfer for a sparse cost matrix.
  */
-int_t _ccrrt_sparse(const uint_t n, cost_t *cc, uint_t *ii, uint_t *kk,
+int_t _ccrrt_sparse(const int_t n, cost_t *cc, int_t *ii, int_t *kk,
                       int_t *free_rows, int_t *x, int_t *y, cost_t *v,
                       cost_t large)
 {
     int_t n_free_rows;
     boolean *unique;
 
-    for (uint_t i = 0; i < n; i++) {
+    for (int_t i = 0; i < n; i++) {
         x[i] = -1;
         v[i] = large;
         y[i] = 0;
     }
-    for (uint_t i = 0; i < n; i++) {
-        for (uint_t k = ii[i]; k < ii[i+1]; k++) {
+    for (int_t i = 0; i < n; i++) {
+        for (int_t k = ii[i]; k < ii[i+1]; k++) {
             const int_t j = kk[k];
             const cost_t c = cc[k];
             if (c < v[j]) {
@@ -47,15 +47,15 @@ int_t _ccrrt_sparse(const uint_t n, cost_t *cc, uint_t *ii, uint_t *kk,
         } while (j > 0);
     }
     n_free_rows = 0;
-    for (uint_t i = 0; i < n; i++) {
+    for (int_t i = 0; i < n; i++) {
         if (x[i] < 0) {
             free_rows[n_free_rows++] = i;
         } else if (unique[i]) {
             const int_t j = x[i];
             cost_t min = LARGE;
-            uint_t k = ii[i];
+            int_t k = ii[i];
             cost_t cj2 = 0;
-            for (uint_t j2 = 0; j2 < n; j2++) {
+            for (int_t j2 = 0; j2 < n; j2++) {
                 if(k < ii[i + 1] && kk[k] == j2) {
                     cj2 = cc[k];
                     k++;
@@ -63,7 +63,7 @@ int_t _ccrrt_sparse(const uint_t n, cost_t *cc, uint_t *ii, uint_t *kk,
                     cj2 = large;
                 }
                 // const int_t j2 = kk[k];
-                if (j2 == (uint_t)j) {
+                if (j2 == (int_t)j) {
                     continue;
                 }
                 const cost_t c = cj2 - v[j2];
@@ -84,12 +84,12 @@ int_t _ccrrt_sparse(const uint_t n, cost_t *cc, uint_t *ii, uint_t *kk,
 /** Augmenting row reduction for a sparse cost matrix.
  */
 int_t _carr_sparse(
-    const uint_t n, cost_t *cc, uint_t *ii, uint_t *kk,
-    const uint_t n_free_rows,
+    const int_t n, cost_t *cc, int_t *ii, int_t *kk,
+    const int_t n_free_rows,
     int_t *free_rows, int_t *x, int_t *y, cost_t *v,
     cost_t large)
 {
-    uint_t current = 0;
+    int_t current = 0;
     int_t new_free_rows = 0;
     PRINT_INDEX_ARRAY(x, n);
     PRINT_INDEX_ARRAY(y, n);
@@ -105,7 +105,7 @@ int_t _carr_sparse(
         const int_t free_i = free_rows[current++];
         PRINTF("free_i = %d\n", free_i);
         // if (ii[free_i+1] - ii[free_i] > 0) {
-        //     const uint_t k = ii[free_i];
+        //     const int_t k = ii[free_i];
         //     j1 = kk[k];
         //     v1 = cc[k] - v[j1];
         // } else {
@@ -115,7 +115,7 @@ int_t _carr_sparse(
         // }
         j1 = 0;
         if (ii[free_i+1] - ii[free_i] > 0 && kk[ii[free_i]] == 0) {
-            const uint_t k = ii[free_i];
+            const int_t k = ii[free_i];
             v1 = cc[k] - v[j1];
         } else {
             v1 = large - v[0];
@@ -123,17 +123,17 @@ int_t _carr_sparse(
         j2 = -1;
         v2 = LARGE;
         // meaning this loop doesn't run
-        // for (uint_t k = ii[free_i]+1; k < ii[free_i+1]; k++) {
+        // for (int_t k = ii[free_i]+1; k < ii[free_i+1]; k++) {
         //     PRINTF("%d = %f %d = %f\n", j1, v1, j2, v2);
         //     const int_t j = kk[k];
         //     const cost_t c = cc[k] - v[j];
 
-        uint_t k = ii[free_i];
+        int_t k = ii[free_i];
         if( kk[k] == 0 ){
             k++;
         }
         cost_t cj = 0;
-        for (uint_t j = 1; j < n; j++) {
+        for (int_t j = 1; j < n; j++) {
             if(k < ii[free_i+1] && kk[k] == j) {
                 PRINTF("GOOD ONE %d ", j);
                 cj = cc[k];
@@ -183,11 +183,11 @@ int_t _carr_sparse(
 
 /** Find columns with minimum d[j] and put them on the SCAN list.
  */
-uint_t _find_sparse_1(const uint_t n, uint_t lo, cost_t *d, int_t *cols, int_t *y)
+int_t _find_sparse_1(const int_t n, int_t lo, cost_t *d, int_t *cols, int_t *y)
 {
-    uint_t hi = lo + 1;
+    int_t hi = lo + 1;
     cost_t mind = d[cols[lo]];
-    for (uint_t k = hi; k < n; k++) {
+    for (int_t k = hi; k < n; k++) {
         int_t j = cols[k];
         if (d[j] <= mind) {
             if (d[j] < mind) {
@@ -204,11 +204,11 @@ uint_t _find_sparse_1(const uint_t n, uint_t lo, cost_t *d, int_t *cols, int_t *
 
 /** Find columns with minimum d[j] and put them on the SCAN list.
  */
-int_t _find_sparse_2(cost_t *d, int_t *scan, const uint_t n_todo, int_t *todo, boolean *done, cost_t large)
+int_t _find_sparse_2(cost_t *d, int_t *scan, const int_t n_todo, int_t *todo, boolean *done, cost_t large)
 {
     int_t hi = 0;
     cost_t mind = large;
-    for (uint_t k = 0; k < n_todo; k++) {
+    for (int_t k = 0; k < n_todo; k++) {
         int_t j = todo[k];
         if (done[j]) {
             continue;
@@ -229,13 +229,13 @@ int_t _find_sparse_2(cost_t *d, int_t *scan, const uint_t n_todo, int_t *todo, b
  * decrease d of the TODO columns using the SCAN column.
  */
 int_t _scan_sparse_1(
-    const uint_t n, cost_t *cc, uint_t *ii, uint_t *kk,
-    uint_t *plo, uint_t *phi,
+    const int_t n, cost_t *cc, int_t *ii, int_t *kk,
+    int_t *plo, int_t *phi,
     cost_t *d, int_t *cols, int_t *pred,
     int_t *y, cost_t *v, cost_t large)
 {
-    uint_t lo = *plo;
-    uint_t hi = *phi;
+    int_t lo = *plo;
+    int_t hi = *phi;
     cost_t h, cred_ij;
 
     int_t *rev_kk;
@@ -246,10 +246,10 @@ int_t _scan_sparse_1(
         int_t j = cols[lo++];
         const int_t i = y[j];
         const cost_t mind = d[j];
-        for (uint_t k = 0; k < n; k++) {
+        for (int_t k = 0; k < n; k++) {
             rev_kk[k] = -1;
         }
-        for (uint_t k = ii[i]; k < ii[i+1]; k++) {
+        for (int_t k = ii[i]; k < ii[i+1]; k++) {
             const int_t j = kk[k];
             rev_kk[j] = k;
         }
@@ -264,7 +264,7 @@ int_t _scan_sparse_1(
         }
         PRINTF("i=%d j=%d kj=%d h=%f\n", i, j, kj, h);
         // For all columns in TODO
-        for (uint_t k = hi; k < n; k++) {
+        for (int_t k = hi; k < n; k++) {
             j = cols[k];
             PRINTF("?%d kk[%d:%d]=", j, ii[i], ii[i+1]);
             PRINT_INDEX_ARRAY(kk + ii[i], ii[i+1] - ii[i]);
@@ -299,23 +299,23 @@ int_t _scan_sparse_1(
  * decrease d of the TODO columns using the SCAN column.
  */
 int_t _scan_sparse_2(
-    const uint_t n, cost_t *cc, uint_t *ii, uint_t *kk,
-    uint_t *plo, uint_t *phi,
+    const int_t n, cost_t *cc, int_t *ii, int_t *kk,
+    int_t *plo, int_t *phi,
     cost_t *d, int_t *pred,
-    boolean *done, uint_t *pn_ready, int_t *ready, int_t *scan,
-    uint_t *pn_todo, int_t *todo, boolean *added,
+    boolean *done, int_t *pn_ready, int_t *ready, int_t *scan,
+    int_t *pn_todo, int_t *todo, boolean *added,
     int_t *y, cost_t *v)
 {
-    uint_t lo = *plo;
-    uint_t hi = *phi;
-    uint_t n_todo = *pn_todo;
-    uint_t n_ready = *pn_ready;
+    int_t lo = *plo;
+    int_t hi = *phi;
+    int_t n_todo = *pn_todo;
+    int_t n_ready = *pn_ready;
     cost_t h, cred_ij;
 
     int_t *rev_kk;
     NEW(rev_kk, int_t, n);
 
-    for (uint_t k = 0; k < n; k++) {
+    for (int_t k = 0; k < n; k++) {
         rev_kk[k] = -1;
     }
     while (lo != hi) {
@@ -324,7 +324,7 @@ int_t _scan_sparse_2(
         const int_t i = y[j];
         ready[n_ready++] = j;
         const cost_t mind = d[j];
-        for (uint_t k = ii[i]; k < ii[i+1]; k++) {
+        for (int_t k = ii[i]; k < ii[i+1]; k++) {
             const int_t j = kk[k];
             rev_kk[j] = k;
         }
@@ -336,7 +336,7 @@ int_t _scan_sparse_2(
         h = cc[kj] - v[j] - mind;
         PRINTF("i=%d j=%d kj=%d h=%f\n", i, j, kj, h);
         // For all columns in TODO
-        for (uint_t k = 0; k < ii[i+1] - ii[i]; k++) {
+        for (int_t k = 0; k < ii[i+1] - ii[i]; k++) {
             j = kk[ii[i] + k];
             if (done[j]) {
                 continue;
@@ -360,7 +360,7 @@ int_t _scan_sparse_2(
                 }
             }
         }
-        for (uint_t k = ii[i]; k < ii[i+1]; k++) {
+        for (int_t k = ii[i]; k < ii[i+1]; k++) {
             const int_t j = kk[k];
             rev_kk[j] = -1;
         }
@@ -381,34 +381,34 @@ int_t _scan_sparse_2(
  * \return The closest free column index.
  */
 int_t find_path_sparse_1(
-    const uint_t n, cost_t *cc, uint_t *ii, uint_t *kk,
+    const int_t n, cost_t *cc, int_t *ii, int_t *kk,
     const int_t start_i,
     int_t *y, cost_t *v,
     int_t *pred,
     cost_t large)
 {
-    uint_t lo = 0, hi = 0;
+    int_t lo = 0, hi = 0;
     int_t final_j = -1;
-    uint_t n_ready = 0;
+    int_t n_ready = 0;
     int_t *cols;
     cost_t *d;
 
     NEW(cols, int_t, n);
     NEW(d, cost_t, n);
 
-    for (uint_t i = 0; i < n; i++) {
+    for (int_t i = 0; i < n; i++) {
         cols[i] = i;
         d[i] = large;
         pred[i] = start_i;
     }
 
-    // for (uint_t i = ii[start_i]; i < ii[start_i + 1]; i++) {
+    // for (int_t i = ii[start_i]; i < ii[start_i + 1]; i++) {
     //     const int_t j = kk[i];
     //     d[j] = cc[i] - v[j];
     // }
     cost_t cci = 0;
-    uint_t k = ii[start_i];
-    for(uint_t j = 0; j < n; j++) {
+    int_t k = ii[start_i];
+    for(int_t j = 0; j < n; j++) {
         if(k < ii[start_i+1] && j == kk[k] ) {
             cci = cc[k];
             k++;
@@ -426,7 +426,7 @@ int_t find_path_sparse_1(
             hi = _find_sparse_1(n, lo, d, cols, y);
             PRINTF("check %d..%d\n", lo, hi);
             PRINT_INDEX_ARRAY(cols, n);
-            for (uint_t k = lo; k < hi; k++) {
+            for (int_t k = lo; k < hi; k++) {
                 const int_t j = cols[k];
                 if (y[j] < 0) {
                     final_j = j;
@@ -447,7 +447,7 @@ int_t find_path_sparse_1(
     PRINT_INDEX_ARRAY(cols, n);
     {
         const cost_t mind = d[cols[lo]];
-        for (uint_t k = 0; k < n_ready; k++) {
+        for (int_t k = 0; k < n_ready; k++) {
             const int_t j = cols[k];
             v[j] += d[j] - mind;
         }
@@ -467,16 +467,16 @@ int_t find_path_sparse_1(
  * \return The closest free column index.
  */
 int_t find_path_sparse_2(
-    const uint_t n, cost_t *cc, uint_t *ii, uint_t *kk,
+    const int_t n, cost_t *cc, int_t *ii, int_t *kk,
     const int_t start_i,
     int_t *y, cost_t *v,
     int_t *pred,
     cost_t large)
 {
-    uint_t lo = 0, hi = 0;
+    int_t lo = 0, hi = 0;
     int_t final_j = -1;
-    uint_t n_ready = 0;
-    uint_t n_todo = (ii[start_i + 1] - ii[start_i]);
+    int_t n_ready = 0;
+    int_t n_todo = (ii[start_i + 1] - ii[start_i]);
     boolean *done, *added;
     int_t *ready, *scan, *todo;
     cost_t *d;
@@ -490,11 +490,11 @@ int_t find_path_sparse_2(
 
     memset(done, FALSE, n);
     memset(added, FALSE, n);
-    for (uint_t i = 0; i < n; i++) {
+    for (int_t i = 0; i < n; i++) {
         d[i] = large;
         pred[i] = start_i;
     }
-    for (uint_t i = ii[start_i]; i < ii[start_i + 1]; i++) {
+    for (int_t i = ii[start_i]; i < ii[start_i + 1]; i++) {
         const int_t j = kk[i];
         d[j] = cc[i] - v[j];
         todo[i - ii[start_i]] = j;
@@ -517,7 +517,7 @@ int_t find_path_sparse_2(
             if (!hi) {
                 // XXX: the assignment is unsolvable, lets try to return
                 // something reasonable nevertheless.
-                for (uint_t j = 0; j < n; j++) {
+                for (int_t j = 0; j < n; j++) {
                     if (!done[j] && y[j] < 0) {
                         final_j = j;
                     }
@@ -526,7 +526,7 @@ int_t find_path_sparse_2(
                 break;
             }
             ASSERT(hi > lo);
-            for (uint_t k = lo; k < hi; k++) {
+            for (int_t k = lo; k < hi; k++) {
                 const int_t j = scan[k];
                 if (y[j] < 0) {
                     final_j = j;
@@ -559,7 +559,7 @@ int_t find_path_sparse_2(
     PRINTF("found final_j=%d\n", final_j);
     {
         const cost_t mind = d[scan[lo]];
-        for (uint_t k = 0; k < n_ready; k++) {
+        for (int_t k = 0; k < n_ready; k++) {
             const int_t j = ready[k];
             v[j] += d[j] - mind;
         }
@@ -578,13 +578,13 @@ int_t find_path_sparse_2(
 /** Find path using one of the two find_path variants selected based on sparsity.
  */
 int_t find_path_sparse_dynamic(
-    const uint_t n, cost_t *cc, uint_t *ii, uint_t *kk,
+    const int_t n, cost_t *cc, int_t *ii, int_t *kk,
     const int_t start_i,
     int_t *y, cost_t *v,
     int_t *pred,
     cost_t large)
 {
-    const uint_t n_i = ii[start_i+1] - ii[start_i];
+    const int_t n_i = ii[start_i+1] - ii[start_i];
     // XXX: wouldnt it be better to decide for the whole matrix?
     if (n_i > 0.25 * n) {
         return find_path_sparse_1(n, cc, ii, kk, start_i, y, v, pred, large);
@@ -595,9 +595,9 @@ int_t find_path_sparse_dynamic(
 
 
 typedef int_t (*fp_function_t)(
-        const uint_t, cost_t *, uint_t *, uint_t *, const int_t, int_t *, cost_t *, int_t *, cost_t large);
+        const int_t, cost_t *, int_t *, int_t *, const int_t, int_t *, cost_t *, int_t *, cost_t large);
 
-fp_function_t get_better_find_path(const uint_t n, uint_t *ii)
+fp_function_t get_better_find_path(const int_t n, int_t *ii)
 {
     const double sparsity = ii[n] / (double)(n * n);
     if (sparsity > 0.25) {
@@ -613,8 +613,8 @@ fp_function_t get_better_find_path(const uint_t n, uint_t *ii)
 /** Augment for a sparse cost matrix.
  */
 int_t _ca_sparse(
-    const uint_t n, cost_t *cc, uint_t *ii, uint_t *kk,
-    const uint_t n_free_rows,
+    const int_t n, cost_t *cc, int_t *ii, int_t *kk,
+    const int_t n_free_rows,
     int_t *free_rows, int_t *x, int_t *y, cost_t *v,
     int fp_version, cost_t large)
 {
@@ -632,7 +632,7 @@ int_t _ca_sparse(
 
     for (int_t *pfree_i = free_rows; pfree_i < free_rows + n_free_rows; pfree_i++) {
         int_t i = -1, j;
-        uint_t k = 0;
+        int_t k = 0;
 
         PRINTF("looking at free_i=%d\n", *pfree_i);
         j = fp(n, cc, ii, kk, *pfree_i, y, v, pred, large);
@@ -660,7 +660,7 @@ int_t _ca_sparse(
 /** Solve square sparse LAP.
  */
 int lapmod_internal(
-    const uint_t n, cost_t *cc, uint_t *ii, uint_t *kk,
+    const int_t n, cost_t *cc, int_t *ii, int_t *kk,
     int_t *x, int_t *y, fp_t fp_version, cost_t large)
 {
     int ret;
